==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-angular-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var ScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeries, _super);
    function ScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterSeries.$;
        _this.sb = new ScatterFrame();
        _this.sd = new ScatterFrame();
        _this.r9 = new ScatterFrame();
        return _this;
    }
    ScatterSeries.prototype.get_c5 = function () {
        return true;
    };
    ScatterSeries.prototype.by = function () {
        return new ScatterSeriesView(this);
    };
    ScatterSeries.prototype.g0 = function () {
        return 0.7;
    };
    ScatterSeries.prototype.qf = function () {
        if (this.qe == 0) {
            return 2;
        }
        return _super.prototype.qf.call(this);
    };
    ScatterSeries.prototype.l4 = function (a) {
        _super.prototype.l4.call(this, a);
        this.vg = a;
    };
    ScatterSeries.$t = markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
}(ScatterBase));
export { ScatterSeries };
/**
 * @hidden
 */
var ScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeriesView, _super);
    function ScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.df = null;
        _this.df = a;
        return _this;
    }
    ScatterSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.b1.ql = Defaults.e;
        }
    };
    ScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.ph = a;
        this.e.g1 = 3;
        this.e.g2 = 2;
        this.e.g3 = 2;
        this.e.fb = false;
    };
    ScatterSeriesView.$t = markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
}(ScatterBaseView));
export { ScatterSeriesView };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-angular-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-angular-core";
/**
 * @hidden
 */
var ScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeries, _super);
    function ScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterSeries.$;
        _this.v0 = new ScatterFrame();
        _this.v2 = new ScatterFrame();
        _this.vy = new ScatterFrame();
        return _this;
    }
    ScatterSeries.prototype.get_dx = function () {
        return true;
    };
    ScatterSeries.prototype.cg = function () {
        return new ScatterSeriesView(this);
    };
    ScatterSeries.prototype.iq = function () {
        return 0.7;
    };
    ScatterSeries.prototype.t4 = function () {
        if (this.t3 == 0) {
            return 2;
        }
        return _super.prototype.t4.call(this);
    };
    ScatterSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.ze = a;
    };
    ScatterSeries.$t = markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
}(ScatterBase));
export { ScatterSeries };
/**
 * @hidden
 */
var ScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeriesView, _super);
    function ScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.di = null;
        _this.di = a;
        return _this;
    }
    ScatterSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.ua = Defaults.e;
        }
    };
    ScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.s6 = a;
        this.e.ir = 3;
        this.e.is = 2;
        this.e.it = 2;
        this.e.gj = false;
    };
    ScatterSeriesView.$t = markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
}(ScatterBaseView));
export { ScatterSeriesView };
